==> metasploit-6.4.64-1-x86_64.pkg.tar.zst: opt/metasploit/spec/modules_spec.rb <==
require 'spec_helper'

RSpec.describe 'modules', :content do
  modules_pathname = Pathname.new(__FILE__).parent.parent.join('modules')

  it_should_behave_like 'all modules with module type can be instantiated',
                        module_type: 'auxiliary',
                        modules_pathname: modules_pathname,
                        type_directory: 'auxiliary'

  it_should_behave_like 'all modules with module type can be instantiated',
                        module_type: 'encoder',
                        modules_pathname: modules_pathname,
                        type_directory: 'encoders'

  it_should_behave_like 'all modules with module type can be instantiated',
                        module_type: 'exploit',
                        modules_pathname: modules_pathname,
                        type_directory: 'exploits'

  it_should_behave_like 'all modules with module type can be instantiated',
                        module_type: 'nop',
                        modules_pathname: modules_pathname,
                        type_directory: 'nops'

  it_should_behave_like 'all modules with module type can be instantiated',
                        module_type: 'post',
                        modules_pathname: modules_pathname,
                        type_directory: 'posts'
  it_should_behave_like 'all modules with module type can be instantiated',
                        module_type: 'payload',
                        modules_pathname: modules_pathname,
                        type_directory: 'payload'
end

==> metasploit-6.4.92-1-x86_64.pkg.tar.zst: opt/metasploit/spec/modules_spec.rb <==
require 'spec_helper'

RSpec.describe 'modules', :content do
  modules_pathname = Pathname.new(__FILE__).parent.parent.join('modules')

  it_should_behave_like 'all modules with module type can be instantiated',
                        module_type: 'auxiliary',
                        modules_pathname: modules_pathname,
                        type_directory: 'auxiliary'

  it_should_behave_like 'all modules with module type can be instantiated',
                        module_type: 'encoder',
                        modules_pathname: modules_pathname,
                        type_directory: 'encoders'

  it_should_behave_like 'all modules with module type can be instantiated',
                        module_type: 'exploit',
                        modules_pathname: modules_pathname,
                        type_directory: 'exploits'

  it_should_behave_like 'all modules with module type can be instantiated',
                        module_type: 'evasion',
                        modules_pathname: modules_pathname,
                        type_directory: 'evasion'

  it_should_behave_like 'all modules with module type can be instantiated',
                        module_type: 'nop',
                        modules_pathname: modules_pathname,
                        type_directory: 'nops'

  it_should_behave_like 'all modules with module type can be instantiated',
                        module_type: 'payload',
                        modules_pathname: modules_pathname,
                        type_directory: 'payload'

  it_should_behave_like 'all modules with module type can be instantiated',
                        module_type: 'post',
                        modules_pathname: modules_pathname,
                        type_directory: 'post'
end
